# Snake

Command-line version of the classic Snake game.

![GIF showing gameplay](https://raw.githubusercontent.com/Ruben9922/snake-cmd/master/screenshot1.gif)

## Usage
You should be able to run the application using the following command:
```bash
ruben-snake-cmd
```
Note that I've only tested this on Linux.

The application should generally be self-explanatory.

One thing to note is the settings screen, reached by pressing <kbd>S</kbd> on the title screen. Currently, the only option is to enable/disable the snake wrapping around the edge of the window by pressing <kbd>B</kbd>. If disabled, the snake will "die" on reaching the edge of the window.

There is also a controls screen, reached by pressing <kbd>C</kbd> on the title screen.

## In-Game Controls

| Key(s) | Action |
|-------------------------------------------------------|------------------|
| <kbd>←</kbd>, <kbd>↑</kbd>, <kbd>→</kbd>, <kbd>↓</kbd> | Change direction |
| <kbd>Q</kbd> | End game |

Note that these only apply in-game and not on other screens, such as the title screen or settings screen.
